@@ -33,6 +33,16 @@ setMethod("Ops", signature(e1 = "array", e2 = "mpfr"),
 	      stop(gettextf("'%s'(array,mpfr) method is not implemented yet",
 			    .Generic)))
 
+setMethod("Ops", signature(e1 = "mpfr", e2 = "bigz"),
+	  function(e1, e2) callGeneric(e1, .bigz2mpfr(e2)))
+setMethod("Ops", signature(e1 = "bigz", e2 = "mpfr"),
+	  function(e1, e2) callGeneric(.bigz2mpfr(e1), e2))
+
+setMethod("Ops", signature(e1 = "mpfr", e2 = "bigq"),
+	  function(e1, e2) callGeneric(e1, .bigq2mpfr(e2)))
+setMethod("Ops", signature(e1 = "bigq", e2 = "mpfr"),
+	  function(e1, e2) callGeneric(.bigq2mpfr(e1), e2))
+
 
 setMethod("Logic", signature(e1 = "mpfr", e2 = "mpfr"),
 	  function(e1, e2) callGeneric(as(e1, "numeric"),
