@@ -19,21 +19,23 @@ u <- 7*x - 2
 stopifnot(all.equal(pnorm(as.numeric(u)),
 		    as.numeric(pnorm(u)), tol = 1e-14))
 ## systematic random input testing:
+set.seed(101)
 nSim <- 50
 n2 <- 100
 for(n in 1:nSim) {
     N <- rpois(1, lambda=n2)
-    x <- rnorm(N)
+    N3 <- N %/% 3
+    x <- c(rnorm(N-N3), 10*rt(N3, df=1.25))# <- some large values
     m <- rnorm(N, sd = 1/32)
     s <- rlnorm(N, sd = 1/8)
+    cEps <- .Machine$double.eps
     for(LOG in c(TRUE,FALSE))
         for(L.T in c(TRUE,FALSE)) {
             p. <- pnorm( x, m=m,sd=s, log.p=LOG, lower.tail=L.T)
-            stopifnot(all.equal(p., pnorm(mpfr(x, precBits=48),m=m,sd=s, log.p=LOG, lower.tail=L.T),
-                                tol = 64e-16))
-            stopifnot(all.equal(p.,
-                                pnorm(mpfr(x, precBits=60),m=m,sd=s, log.p=LOG, lower.tail=L.T),
-                                tol = 2*.Machine$double.eps))
+            stopifnot(all.equal(p., pnorm(mpfr(x, precBits= 48), m=m,sd=s, log.p=LOG, lower.tail=L.T),
+                                tol = 128 * cEps))
+            stopifnot(all.equal(p., pnorm(mpfr(x, precBits= 60), m=m,sd=s, log.p=LOG, lower.tail=L.T),
+                                tol = 2 * cEps))
         }
     cat(".")
 };cat("\n")
